@@ -11,6 +11,7 @@ def _dl_to_dict(dl):
         d[key] = value
     return d
 
+
 def _prefix_keys(old_dict, prefix):
     """Adds a prefix to all keys in a dict"""
     new_dict = {}
@@ -19,13 +20,14 @@ def _prefix_keys(old_dict, prefix):
         new_dict[new_key] = old_dict[key]
     return new_dict
 
+
 def _table_to_dict(table):
     data = {}
     years = [x.text.strip() for x in table.select("thead th.data-pager__page")]
     for tr in table.select("tbody tr"):
         try:
             key = tr.select_one("th").text.strip()
-        except:
+        except Exception:
             continue
         values = [x.text.strip() for x in tr.select("td.data-pager__page")]
         data[key] = list(zip(years, values))
